fasttree 0.2.0

Bezpieczny, idiomatyczny wrapper Rust nad FastTree (Nim) — Store/Manifest z RAII i Result<T, FastTreeError>.
docs.rs failed to build fasttree-0.2.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.